@@ -8,32 +8,29 @@ Text::Shirasu::Node - Shirasu Node Object
 
 =head1 SYNOPSIS
 
-	use utf8;
+    use utf8;
     use feature ':5.10';
     use Text::Shirasu;
     my $ts = Text::Shirasu->new;
-	
-	$ts->parse("昨日の晩御飯は「鮭のふりかけ」と「味噌汁」だけでした。");
+    
+    $ts->parse("昨日の晩御飯は「鮭のふりかけ」と「味噌汁」だけでした。");
 
-
-	for my $node (@{ $ts->nodes }) {
-	    say $node->id;
-		say $node->surface;
-		say $node->length;
-		say $node->rlength;
-		say $node->feature;
-		say $node->next;
-		say $node->prev;
-		say $node->rcattr;
-		say $node->lcattr;
-		say $node->stat;
-		say $node->isbest;
-		say $node->alpha;
-		say $node->beta;
-		say $node->prob;
-		say $node->wcost;
-		say $node->cost;
-	}
+    for my $node (@{ $ts->nodes }) {
+        say $node->id;
+        say $node->surface;
+        say $node->length;
+        say $node->rlength;
+        say for @{ $node->feature };
+        say $node->rcattr;
+        say $node->lcattr;
+        say $node->stat;
+        say $node->isbest;
+        say $node->alpha;
+        say $node->beta;
+        say $node->prob;
+        say $node->wcost;
+        say $node->cost;
+    }
 
 =head1 DESCRIPTION
 
@@ -46,6 +43,7 @@ sub surface { $_[0]->{surface} }
 sub feature { $_[0]->{feature} }
 sub length  { $_[0]->{length}  }
 sub rlength { $_[0]->{rlength} }
+sub rcattr  { $_[0]->{rcattr}  }
 sub lcattr  { $_[0]->{lcattr}  }
 sub stat    { $_[0]->{stat}    }
 sub isbest  { $_[0]->{isbest}  }
